@@ -12,7 +12,7 @@ logger = logging.getLogger(__name__)
 DEFAULT_PORT = 5500
 
 
-def live_reload(files=None, port=DEFAULT_PORT, throttle=3, fns=None, callback=None):
+def live_reload(files=None, port=DEFAULT_PORT, throttle=3, fns=None, reload=True, callback=None):
     """
     Start python livereload server, watching
     the given files using fabuild's watch function.  This
@@ -23,6 +23,7 @@ def live_reload(files=None, port=DEFAULT_PORT, throttle=3, fns=None, callback=No
     :param port: Port to run server on
     :param fns: Function list to run on watch trigger
     :param callback: Custom callback on watch trigger
+    :param reload: True to reload immediately
     :param throttle: Throttling for watch event
     :return: void
     """
@@ -45,6 +46,9 @@ def live_reload(files=None, port=DEFAULT_PORT, throttle=3, fns=None, callback=No
         if callback:
             callback(event, fns)
 
+    if reload:
+        get('http://127.0.0.1:%d/forcereload' % (port))
+
     watch(fns, ".", files=files, callback=reload_file,
           recursive=True, throttle=throttle, keep_alive=True)
 
